# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/identity_provider.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/identity_provider.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgateway/identity_provider.proto\x12\x07gateway\x1a\x1b\x62uf/validate/validate.proto\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb4\x03\n\x10IdentityProvider\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x0b\xe2\x41\x01\x02\xbaH\x04r\x02\x18?\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x35\n\x0bupdate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12*\n\x0bsaml_config\x18\x05 \x01(\x0b\x32\x13.gateway.SamlConfigH\x00\x12*\n\x0boidc_config\x18\x06 \x01(\x0b\x32\x13.gateway.OidcConfigH\x00:\x96\x01\xea\x41\x85\x01\n!api.fireworks.ai/IdentityProvider\x12;accounts/{AccountId}/identityProviders/{IdentityProviderId}*\x11identityProviders2\x10identityProvider\x82\xf1\x04\t\n\x07\x41\x63\x63ountB\x08\n\x06\x63onfig\"(\n\nSamlConfig\x12\x1a\n\x0cmetadata_url\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\\\n\nOidcConfig\x12\x18\n\nissuer_url\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tclient_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1b\n\rclient_secret\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\"q\n\x1d\x43reateIdentityProviderRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12:\n\x11identity_provider\x18\x02 \x01(\x0b\x32\x19.gateway.IdentityProviderB\x04\xe2\x41\x01\x02\"0\n\x1aGetIdentityProviderRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"}\n\x1cListIdentityProvidersRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\"\x83\x01\n\x1dListIdentityProvidersResponse\x12\x35\n\x12identity_providers\x18\x01 \x03(\x0b\x32\x19.gateway.IdentityProvider\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"\x92\x01\n\x1dUpdateIdentityProviderRequest\x12:\n\x11identity_provider\x18\x01 \x01(\x0b\x32\x19.gateway.IdentityProviderB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"3\n\x1d\x44\x65leteIdentityProviderRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.identity_provider_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_IDENTITYPROVIDER'].fields_by_name['name']._loaded_options = None
  _globals['_IDENTITYPROVIDER'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_IDENTITYPROVIDER'].fields_by_name['display_name']._loaded_options = None
  _globals['_IDENTITYPROVIDER'].fields_by_name['display_name']._serialized_options = b'\342A\001\002\272H\004r\002\030?'
  _globals['_IDENTITYPROVIDER'].fields_by_name['create_time']._loaded_options = None
  _globals['_IDENTITYPROVIDER'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_IDENTITYPROVIDER'].fields_by_name['update_time']._loaded_options = None
  _globals['_IDENTITYPROVIDER'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_IDENTITYPROVIDER']._loaded_options = None
  _globals['_IDENTITYPROVIDER']._serialized_options = b'\352A\205\001\n!api.fireworks.ai/IdentityProvider\022;accounts/{AccountId}/identityProviders/{IdentityProviderId}*\021identityProviders2\020identityProvider\202\361\004\t\n\007Account'
  _globals['_SAMLCONFIG'].fields_by_name['metadata_url']._loaded_options = None
  _globals['_SAMLCONFIG'].fields_by_name['metadata_url']._serialized_options = b'\342A\001\002'
  _globals['_OIDCCONFIG'].fields_by_name['issuer_url']._loaded_options = None
  _globals['_OIDCCONFIG'].fields_by_name['issuer_url']._serialized_options = b'\342A\001\002'
  _globals['_OIDCCONFIG'].fields_by_name['client_id']._loaded_options = None
  _globals['_OIDCCONFIG'].fields_by_name['client_id']._serialized_options = b'\342A\001\002'
  _globals['_OIDCCONFIG'].fields_by_name['client_secret']._loaded_options = None
  _globals['_OIDCCONFIG'].fields_by_name['client_secret']._serialized_options = b'\342A\001\002'
  _globals['_CREATEIDENTITYPROVIDERREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEIDENTITYPROVIDERREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEIDENTITYPROVIDERREQUEST'].fields_by_name['identity_provider']._loaded_options = None
  _globals['_CREATEIDENTITYPROVIDERREQUEST'].fields_by_name['identity_provider']._serialized_options = b'\342A\001\002'
  _globals['_GETIDENTITYPROVIDERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETIDENTITYPROVIDERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTIDENTITYPROVIDERSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTIDENTITYPROVIDERSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTIDENTITYPROVIDERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTIDENTITYPROVIDERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTIDENTITYPROVIDERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTIDENTITYPROVIDERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTIDENTITYPROVIDERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTIDENTITYPROVIDERSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEIDENTITYPROVIDERREQUEST'].fields_by_name['identity_provider']._loaded_options = None
  _globals['_UPDATEIDENTITYPROVIDERREQUEST'].fields_by_name['identity_provider']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEIDENTITYPROVIDERREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEIDENTITYPROVIDERREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEIDENTITYPROVIDERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEIDENTITYPROVIDERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_IDENTITYPROVIDER']._serialized_start=224
  _globals['_IDENTITYPROVIDER']._serialized_end=660
  _globals['_SAMLCONFIG']._serialized_start=662
  _globals['_SAMLCONFIG']._serialized_end=702
  _globals['_OIDCCONFIG']._serialized_start=704
  _globals['_OIDCCONFIG']._serialized_end=796
  _globals['_CREATEIDENTITYPROVIDERREQUEST']._serialized_start=798
  _globals['_CREATEIDENTITYPROVIDERREQUEST']._serialized_end=911
  _globals['_GETIDENTITYPROVIDERREQUEST']._serialized_start=913
  _globals['_GETIDENTITYPROVIDERREQUEST']._serialized_end=961
  _globals['_LISTIDENTITYPROVIDERSREQUEST']._serialized_start=963
  _globals['_LISTIDENTITYPROVIDERSREQUEST']._serialized_end=1088
  _globals['_LISTIDENTITYPROVIDERSRESPONSE']._serialized_start=1091
  _globals['_LISTIDENTITYPROVIDERSRESPONSE']._serialized_end=1222
  _globals['_UPDATEIDENTITYPROVIDERREQUEST']._serialized_start=1225
  _globals['_UPDATEIDENTITYPROVIDERREQUEST']._serialized_end=1371
  _globals['_DELETEIDENTITYPROVIDERREQUEST']._serialized_start=1373
  _globals['_DELETEIDENTITYPROVIDERREQUEST']._serialized_end=1424
# @@protoc_insertion_point(module_scope)
